herbs = [
    "garlic clove",
    "garlic",
    "cilantro",
    "green onion",
    "basil",
    "garlic powder",
    "thyme",
    "celery",
    "coriander",
    "scallion",
    "curry powder",
    "rosemary",
    "mint",
    "basil leaf",
    "dill",
    "italian seasoning",
    "celery rib",
    "mint leaf",
    "cilantro leaf",
    "sage",
    "spring onion",
    "coriander leaf",
    "fennel seed",
    "coriander seed",
    "lemongrass",
    "tarragon",
    "herb",
    "coriander powder",
    "curry leaf",
    "thyme leaf",
    "dill weed",
    "pesto sauce",
    "garlic paste",
    "sage leaf",
    "fennel bulb",
    "fenugreek seed",
    "red curry paste",
    "curry paste",
    "dill pickle",
    "wonton wrapper",
    "thai basil",
    "fennel",
    "thyme leave",
    "cilantro stem",
    "thyme sprig",
    "mint sprig",
    "celery leaf",
    "savory",
    "basil pesto",
    "rosemary leaf",
    "herbes de provence",
    "fenugreek leaf",
    "rosemary sprig",
    "head garlic",
    "chervil",
    "madras curry powder",
    "fenugreek",
    "tarragon leaf",
    "bulb garlic",
    "garlic granule",
    "dill sprig",
    "rocket",
    "epazote",
    "dill seed",
    "pesto",
    "basil sprig",
    "coriander sprig",
    "spearmint",
    "summer savory",
    "coriander root",
    "wonton skin",
    "sorrel",
    "garlic chive",
    "clove garlic",
    "rib",
    "lemon thyme",
    "garlic flake",
    "tomato garlic",
    "dill leaf",
    "leaf thyme",
    "fennel leaf",
    "green coriander",
    "pandan leaf",
    "celery heart",
    "epazote leaf",
    "fennel powder",
    "italian seasoning mix",
    "garlic head",
    "rib celery",
    "mint extract",
    "celery flake",
    "dill pickle relish",
    "file powder",
    "herb stuffing mix",
    "spring green",
    "taro root",
    "mint sauce",
    "bulb fennel",
    "garlic herb seasoning",
    "garlic juice",
    "thai basil leaf",
    "leaf basil",
    "angelica",
    "cilantro root",
    "coriander cilantro",
    "dill pickle spear",
    "garlic scape",
    "shiso leaf",
    "basil chiffonade",
    "kosher dill pickle",
    "rub",
    "screwpine leaf",
    "gyoza skin",
    "herbes de",
    "baby dill pickle",
    "chinese celery",
    "culantro",
    "irish moss",
    "persimmon pulp",
    "sage sprig",
    "andes mint candy",
    "fine herb",
    "pizza topping",
    "winter savory",
    "cilantro sprig",
    "dill pickle juice",
    "lemon thyme leaf",
    "mint flake",
    "peppermint schnapps",
    "rosemary needle",
    "salt garlic powder",
    "tomato basil garlic",
    "wrapper",
    "de provence",
    "french thyme",
    "garlic basil",
    "goya garlic",
    "kaffir lime zest",
    "licorice",
    "spring",
    "tarragon sprig",
    "torn basil leaf",
    "yellow curry powder",
    "asian basil",
    "culantro cilantro",
    "garlic herb couscous mix",
    "garlic herb spreadable cheese",
    "garlic seasoning",
    "garlic sprout",
    "herb choice",
    "italian seasoning basil",
    "italian seasoning oregano",
    "lemon basil",
    "lemongrass paste",
    "licorice root",
    "mint powder",
    "peppermint",
    "sorrel leaf",
    "spring onion leaf",
    "tomato basil garlic seasoning",
    "wonton",
    "amaranth flour",
    "borage leaf",
    "coriander coarsely",
    "empanada wrapper",
    "fennel green",
    "french tarragon",
    "garlic toast",
    "herb seasoning",
    "mccormick italian seasoning",
    "peppermint leaf",
    "pineapple sage",
    "potato garlic",
    "purple basil",
    "thai holy basil",
    "thai holy basil ok",
    "tomato italian herb",
    "torn arugula leaf",
    "za'atar",
    "amaranth",
    "angelica leaf",
    "basil seasoning",
    "basil seed",
    "borage",
    "celery powder",
    "coriander chutney",
    "coriander seed powder",
    "elephant garlic",
    "elephant garlic clove",
    "extra coriander",
    "fennel head",
    "garlic basil spread",
    "garlic hummus",
    "garlic potato",
    "garlic puree",
    "green garlic clove",
    "head garlic clove",
    "herb garlic feta",
    "herb stuffing cube",
    "herbes de thyme",
    "hyssop",
    "italian seasoning basil oregano",
    "jamaican curry powder",
    "leaf mint",
    "mint candy",
    "mint oreo cooky",
    "mint relish",
    "mint vinaigrette",
    "mugwort",
    "nostimini herb mix",
    "oval",
    "pesto sauce mix",
    "pickle spear",
    "recao",
    "red chicory",
    "salt garlic herb seasoning",
    "spicy curry paste",
    "sprig coriander",
    "sprig lemon thyme",
    "sprig rosemary",
    "spring onion white",
    "taro leaf",
    "thai basil chiffonade",
    "torn basil",
    "vegetable green onion",
    "vietnamese mint",
    "vietnamese pate",
    "white garlic",
    "yellow taro root",
    "aberdeen angus rib",
    "almond coriander",
    "amaranth green",
    "amaranth seed",
    "anchovy essence herb such",
    "andes mint candy dinner",
    "andes mint dinner",
    "andes mint eight dinner",
    "angelica root",
    "at least stem coriander",
    "baby dill gherkin",
    "baby fennel bulb",
    "baby taro root",
    "baharat spice mix curry powder",
    "balsamic basil",
    "basil chiffonade stack",
    "basil paste not",
    "basil spice essence",
    "bicks tangy dill relish",
    "biscuit cheddar garlic",
    "boursin herb",
    "bread fennel seed",
    "breadcrumb basil leaf pecorino",
    "breadcrumb thyme",
    "brisket rub",
    "callisons garlic herb",
    "campbell garlic",
    "celery crosswise",
    "celery diagonally",
    "celery juice",
    "chi taco seasoning green chilies onion",
    "chili paste basil leaf",
    "chipotle powder garlic",
    "chive green onion",
    "chocolate mint extract",
    "choice pizza topping",
    "cilantro lime vinaigrette",
    "cilantro root chinese parsley",
    "cilantro root leaf",
    "citrus seafood rub",
    "classico di genoa pasta sauce pesto",
    "coriander dhaniya powder",
    "coriander do not like cilantro",
    "coriander keep",
    "coriander optional",
    "coriander paste",
    "coriander root well",
    "coriander roughly",
    "coriander seed better",
    "coriander seed cilantro",
    "coriander seed root",
    "coriander seed well",
    "coriander vietnamese",
    "cornmeal thyme dumpling",
    "creamy pesto sauce mix",
    "culantro by half",
    "dandelion leaf",
    "dhaniya powder coriander",
    "dill leaf seed",
    "dill pickle brine",
    "dill pickle chip",
    "dill pickle cube",
    "dill pickle relish juice",
    "dill relish",
    "dozen potsticker gyoza skin",
    "each coriander",
    "elephant",
    "english rib",
    "epicure garlic herb dip mix",
    "farmer market arugula",
    "fennel frond",
    "fennel pollen",
    "few lemon thyme leaf",
    "file powder see",
    "flat leaf coriander",
    "garlic almond",
    "garlic bologna",
    "garlic breadcrumb",
    "garlic breadstick",
    "garlic chutney",
    "garlic ciabatta",
    "garlic green chive",
    "garlic herb",
    "garlic herb breadcrumb",
    "garlic herb marinade",
    "garlic herb sauce mix",
    "garlic kielbasa",
    "garlic lime marinade",
    "garlic parmesan pretzel crisp",
    "garlic powder pepper",
    "garlic salt powder",
    "garlic season",
    "garlic tomato",
    "garlic tomato vinaigrette",
    "gilroy garlic",
    "gourmet garlic basil seasoning",
    "goya bay leaf",
    "grasshopper fudge mint",
    "greek salt seasoning mix",
    "greek seasoning mix",
    "green garlic chive",
    "green methi leaf",
    "green onion diagonally",
    "green onion miso vinaigrette below",
    "green onion part",
    "green onion portion",
    "green onion red",
    "green onion stem",
    "green shiso leaf",
    "grey taro root",
    "head garlic crosswise",
    "herb bread",
    "herb leaf",
    "herb such",
    "herbes",
    "herbes de choice",
    "herbes de herb",
    "herbes de italian herb",
    "herbes de italian seasoning",
    "herbes de marjoram",
    "herbes de napa",
    "herbes de provence combo",
    "herbes de provence simple spice mix from vegetarian time",
    "herbes french herb thyme leaf",
    "hibiscus flower sorrel",
    "hot garlic vinaigrette",
    "hummus garlic",
    "indian coriander",
    "italian dressing seasoning",
    "italian herb mix",
    "italian herb tomato sauce",
    "italian seasoning basil seperatley together",
    "italian seasoning each basil",
    "italian seasoning mix oregano",
    "italian seasoning monkey organic grinder zest",
    "italian seasoning sage",
    "italian seasoning seasoning",
    "italian seasoning sunset",
    "italian seasoning thyme",
    "italian spice basil",
    "jerk rub",
    "junior mint garnish",
    "kosher pickle",
    "kosher pickle lengthwise",
    "kraft classic herb",
    "laughing cow garlic herb cheese",
    "leaf coriander",
    "leaf thai basil",
    "lemon thyme ca n't",
    "lemongrass juice",
    "lemongrass paste below",
    "lemongrass puree",
    "lime garlic salsa",
    "liquid garlic",
    "loosely basil leaf",
    "market",
    "masala paste green chilli onion",
    "mc cormick italian seasoning",
    "mccormick flavor garlic herb seasoning",
    "mccormick garlic powder",
    "mccormick herb marinade",
    "mccormick spicy seasoning garlic chicken seasoning",
    "mint cilantro chutney",
    "mint herbal tea",
    "mint liqueur",
    "mint paste",
    "mint tea leaf",
    "mutton rib",
    "no tomato italian herb",
    "onion cilantro salad",
    "onion garlic powder",
    "onion herb seasoning",
    "onion salt powder garlic",
    "organic celery",
    "oval dill",
    "pak chi",
    "pandan leaf extract",
    "peppermint flavoring",
    "peppermint pattie",
    "pesto alfredo cream sauce",
    "pesto tortellini",
    "petite tomato garlic",
    "philadelphia cooking savory garlic creme",
    "philadelphia herb",
    "philadelphia savory garlic cooking creme",
    "pillsbury garlic breadstick",
    "pizza seasoning italian",
    "pizza seasoning italian dressing",
    "pizza seasoning italian seasoning",
    "progresso garlic breadcrumb",
    "progresso garlic herb breadcrumb",
    "purpose seasoning basil",
    "recao cilantro not",
    "red amaranth leaf",
    "red pimento paste",
    "red shiso leaf",
    "red sorrel bud",
    "relish dill",
    "rib flanken",
    "rosemary bread",
    "rosemary crustini",
    "rosemary edible",
    "rosemary essential oil",
    "rutabaga n't celery",
    "saboot dhania coriander seed",
    "salad leaf rocket",
    "san basil",
    "scallion bulb",
    "scallion oil",
    "schilling italian seasoning",
    "schwartz italian seasoning",
    "scout mint",
    "scwartz italian seasoning",
    "season italian seasoning",
    "seasoning herb etc",
    "shiso leaf choice",
    "shiso leaf see pic",
    "side rib",
    "some coriander",
    "some italian seasoning",
    "southwest seasoning garlic powder",
    "spearmint decorative candy",
    "spice garlic powder",
    "spicy italian seasoning",
    "spicy pesto",
    "spinach leaf basil",
    "sprig cilantro",
    "sprig mint",
    "sprig thyme",
    "spring onion green",
    "spring vidalia onion",
    "summer savory chubritsa",
    "sun italy italian seasoning",
    "sun tomato italian herb",
    "tangy green dill relish",
    "taro",
    "taro root leaf",
    "teff",
    "thai chilli jam",
    "tightly cilantro",
    "tomato garlic polenta",
    "torn cilantro leaf",
    "vegetable summer squash onion green",
    "white coriander seed",
    "white onion spring",
    "white taro root",
    "yautia taro root",
    "yerba buena mint",
    "young arugula leaf",
    "young pandan leaf",
    "za'tar",
]


fruits = [
    "lemon",
    "lime",
    "raisin",
    "avocado",
    "orange",
    "apple",
    "banana",
    "caper",
    "strawberry",
    "mango",
    "apricot",
    "date",
    "cranberry",
    "raspberry",
    "blueberry",
    "currant",
    "peach",
    "pumpkin",
    "cherry",
    "pear",
    "fruit",
    "sultana",
    "prune",
    "applesauce",
    "fig",
    "papaya",
    "berry",
    "watermelon",
    "plantain",
    "blackberry",
    "plum",
    "cantaloupe",
    "grape",
    "squash",
    "kiwi",
    "jam",
    "pomegranate",
    "peel",
    "citron",
    "nectarine",
    "craisins",
    "tangerine",
    "quince",
    "lychee",
    "clementine",
    "melon",
    "kumquat",
    "jelly",
    "lingonberry",
    "barberry",
    "gooseberry",
    "cooking",
    "pawpaw",
    "breadfruit",
    "carambola",
    "elderberry",
    "honeydew",
    "umeboshi",
    "gourd",
    "jackfruit",
    "tamarillo",
    "caperberries",
    "huckleberry",
    "preserve",
    "cucuzza",
    "durian",
    "kokum",
    "loquat",
    "tamarind",
    "tart",
    "blackberrie",
    "calabaza",
    "cherimoya",
    "christophene",
    "feijoa",
    "macapuno",
    "muskmelon",
    "persimmon",
    "acorn",
    "asian",
    "craisin",
    "granadilla",
    "jujube",
    "kabocha",
    "kiwifruit",
    "litchi",
    "mangosteen",
    "passionfruit",
    "salmonberry",
    "tangelo",
    "waxgourd",
    "young",
    "yuzu",
    "zest",
]


vegetables = [
    "onion",
    "tomato",
    "carrot",
    "potato",
    "paprika",
    "zucchini",
    "spinach",
    "cucumber",
    "chive",
    "cabbage",
    "eggplant",
    "leek",
    "lettuce",
    "cayenne",
    "asparagus",
    "horseradish",
    "sauerkraut",
    "vegetable",
    "tomatillo",
    "chilies",
    "radish",
    "parsnip",
    "beet",
    "turnip",
    "chili",
    "broth",
    "okra",
    "kale",
    "arugula",
    "harissa",
    "jicama",
    "rhubarb",
    "rotel",
    "chile",
    "rutabaga",
    "aubergine",
    "courgette",
    "arrowroot",
    "escarole",
    "beetroot",
    "gherkin",
    "tapioca",
    "wasabi",
    "yam",
    "radicchio",
    "capsicum",
    "kumara",
    "stevia",
    "celeriac",
    "swede",
    "endive",
    "chayotes",
    "mesclun",
    "cassava",
    "chayote",
    "frisee",
    "brinjal",
    "cornichons",
    "kohlrabi",
    "fiddlehead",
    "rapini",
    "daikon",
    "tomatoe",
    "bottlegourd",
    # 'marrow',
    "puree",
    "ramp",
    "chard",
    "clean",
    "karela",
    "mirliton",
    "pimenton",
    "tatsoi",
    "korean",
    "yellow",
    "chinese",
    "japanese",
    "jicamas",
    "kucai",
    "mirlitons",
    "mizuna",
    "shoestring",
    "ube",
    "vidalia",
    "yuca",
    "yucca",
]


legumes = [
    "pea",
    "chickpea",
    "bean",
    "lentil",
    "edamame",
    "sprout",
    r"dh?al",
    "rajma",
    "alfalfa",
    "chana",
    "kudzu",
    "pulse",
]


seeds = [
    "chia",
    "anise",
    "cardamom pod",
    "mustard seed",
    "sesame",
    "poppy",
    "sunflower seed",
    "seed",
]



# from utils import with_plural, to_regex
from ..utils import with_plural, to_regex

# from data.ingredient_categories import fruits, vegetables, legumes, herbs
from .ingredient_categories import fruits, vegetables, legumes, herbs

# from data.meat import dictionary as meat_dict
from .meat import dictionary as meat_dict

# from data.ingredients import dictionary as ing_dict
from .ingredients import dictionary as ing_dict

proteins = list(meat_dict.keys())
pasta = ing_dict["pasta"]

drink_list = with_plural(
    [
        "slushy",
        "slushie",
        "colada",
        "old fashioned",
        "bitter",
        "whiskey",
        "liqueur",
        "cider",
        "cappuccino",
        "frappuccino",
        "coffee",
        "espresso",
        "cocktail",
        "beer",
        "wine",
        "rootbeer",
        "drink",
        "juice",
        "tea",
        "milk",
        "moccha",
        "shake",
        "milkshake",
        "smoothie",
        "cocoa",
        "margarita",
        "mojito",
        "smoothie",
        "gin",
        "lemonade",
    ]
)
soup_list = with_plural(
    [
        "minestrone",
        "soup",
        "chowder",
        "bouillabaisse",
        "gazpacho",
        "bisque",
        "bouillon",
        "broth",
        "consomme",
        "consommé",
        "velouté",
        "veloute",
        "vichyssoise",
        "skink",
        "laksa",
        "ramen",
        "goulash",
        "stew",
        "bourguignon",
        "rogan josh",
    ]
)
niche_list = with_plural(
    [
        "vinaigrette",
        "horseradish",
        "compote",
        "sauce",
        "marinade",
        "dip",
        "jam",
        "queso",
        "jus",
        "dressing",
        "bread",
        "spread",
        "preserve",
        "stock",
        "bouillon",
        "salsa",
        "gravy",
    ]
)
dessert_list = with_plural(
    [
        "apple pie",
        "semifreddo",
        "waffle",
        "crepe",
        "pudding",
        "french toast",
        "torta",
        "tiramisu",
        "sundae",
        "madeleine",
        "ice cream",
        "cookie",
        r"muffin",
        r"bar",
        r"cupcake",
        r"brownie",
        r"cheesecake",
        r"pancake",
        "tart",
        "rugelach",
        "chiffon cake",
        r"biscuit",
        r"scone",
        "sorbet",
        "biscotti",
        "galette",
        "granola",
        "buttercream",
        r"doughnut",
        "crumble",
        "shortbread",
        r"mousse",
        "baklava",
        "donut",
    ]
)
sandwich_list = with_plural(
    [
        "panini",
        "sandwich",
        "burrito",
        "burger",
        "taco",
        "bruschetta",
        "baguette",
        "wrap",
        "hot dog",
        "enchilada",
        "ciabatta",
    ]
)
exceptions = ["stock", "broth", "bouillon", "beefsteak"]

title_map = {
    "seafood": to_regex(["ceviche"]),
    "sandwich": to_regex(sandwich_list),
    "pasta": to_regex(pasta + ["pasta", "alfredo"]),
    "sausage": to_regex(["sausage", "sausages", "chorizo"]),
    "casserole": to_regex(["casserole"]),
    "dessert": to_regex(dessert_list),
    "soup": to_regex(soup_list),
}

ing_keys = proteins + ["pasta"]

ing_map = {"spicy food": "spicy pepper"}

root_map = {
    "sandwich": to_regex(sandwich_list),
    "vegetarian": to_regex(
        with_plural(
            vegetables + ["mushroom", "portobell", "brussels sprouts", "tofu", "beans"]
        )
    ),
    "salad": to_regex(["(?<!fruit )salad"]),
    "pasta": to_regex(pasta + ["pasta", "alfredo"]),
    "dessert": to_regex(dessert_list),
    "niche": to_regex(niche_list),
    "soup": to_regex(soup_list),
    "drink": rf"{to_regex(drink_list)}$",
    "pizza": to_regex(["pizza", "calzone", "buffalina", "margherita"]),
    "sushi": to_regex(
        ["nigiri", "sashimi", "chirashi", "oshizushi", "temaki", "uramaki", "sushi"]
    ),
}


models = {
    "fish": [
        "seafood",
        "tuna",
        "lean fish",
        "salmon",
        "crustacean",
        "fatty fish",
        "other seafood",
        "octopus",
    ],
    "white-meat": [
        "poultry",
    ],
    "red-meat": [
        "game bird",
        "beef",
        "pork",
        "sausage",
        "game",
        "lamb",
        "bacon",
        "liver",
    ],
    "sweets": [
        "dessert",
    ],
    "other": [
        "soup",
        "spicy food",
        "niche",
        "ham",
        "sandwich",
        "pizza",
        "pasta",
        "casserole",
        "vegetarian",
        "salad",
    ],
}



['onion',
 'tomato',
 'carrot',
 'potato',
 'zucchini',
 'spinach',
 'cucumber',
 'chive',
 'cabbage',
 'eggplant',
 'leek',
 'lettuce',
 'asparagus',
 'vegetable',
 'tomatillo',
 'radish',
 'parsnip',
 'beet',
 'turnip',
 'okra',
 'kale',
 'arugula',
 'jicama',
 'rhubarb',
 'rutabaga',
 'aubergine',
 'courgette',
 'arrowroot',
 'escarole',
 'beetroot',
 'gherkin',
 'tapioca',
 'wasabi',
 'yam',
 'radicchio',
 'capsicum',
 'kumara',
 'stevia',
 'celeriac',
 'swede',
 'endive',
 'mesclun',
 'cassava',
 'chayote',
 'frisee',
 'brinjal',
 'cornichons',
 'kohlrabi',
 'fiddlehead',
 'rapini',
 'daikon',
 'tomatoe',
 'bottlegourd',
 'marrow',
 'ramp',
 'chard',
 'karela',
 'tatsoi',
 'kucai',
 'mirliton',
 'mizuna',
 'ube',
 'vidalia',
 'yuca',
 'yucca']